import React, { useEffect } from "react";
import {
	Button,
	Dialog,
	DialogActions,
	DialogContent,
	DialogTitle,
	TextField,
} from "@mui/material";
import { useForm, Controller } from "react-hook-form";

//By Jaanvi : Edit Model :: 11-feb-25
interface AddEditCategoryModalProps {
	open: boolean;
	handleClose: () => void;
	handleUpdate: (
		id: string,
		name: string,
		email: string,
		phone: string,
		registeredAddress: string
	) => void;
	editRow: any;
	handleAdd: Function;
}

interface FormData {
	name: string;
	email: string;
	phone: string;
	registeredAddress: string;
}

const AddEditCategoryModal: React.FC<AddEditCategoryModalProps> = ({
	open,
	handleClose,
	editRow,
	handleUpdate,
	handleAdd,
}) => {
	const {
		control,
		handleSubmit,
		formState: { errors },
		setValue,
		reset,
	} = useForm<FormData>({
		defaultValues: {
			name: "",
			email: "",
			phone: "",
			registeredAddress: "",
		},
	});

	const onSubmit = (data: FormData) => {
		if (editRow) {
			handleUpdate(
				editRow.id,
				data.name,
				data.email,
				data.phone,
				data.registeredAddress
			);
		} else {
			// Call handleAdd if adding new admin
			handleAdd(
				data.name,
				data.email,
				data.phone,
				data.registeredAddress
			);
		}
		handleClose();
		reset();
	};

	useEffect(() => {
		if (editRow) {
			setValue("name", editRow.name);
			setValue("email", editRow.role);
			setValue("phone", editRow.phone);
			setValue("email", editRow.email);
			setValue("registeredAddress", editRow.registeredAddress);
		} else {
			reset();
		}
	}, [editRow, setValue, reset]);

	return (
		<>
			<Dialog
				open={open}
				onClose={handleClose}
				maxWidth="md"
				fullWidth
				PaperProps={{
					component: "form",
					onSubmit: handleSubmit(onSubmit),
				}}
			>
				<DialogTitle>{editRow ? "Edit" : "Add"} Admin</DialogTitle>
				<DialogContent>
					<Controller
						name="name"
						control={control}
						rules={{
							required: "Admin Name is required",
						}}
						render={({ field }) => (
							<TextField
								{...field}
								autoFocus
								required
								margin="dense"
								label="Admin Name"
								type="text"
								fullWidth
								variant="standard"
								error={!!errors.name}
								helperText={errors.name?.message}
							/>
						)}
					/>

					<Controller
						name="email"
						control={control}
						rules={{
							required: "Email is required",
						}}
						render={({ field }) => (
							<TextField
								{...field}
								margin="dense"
								label="Email"
								type="text"
								fullWidth
								variant="standard"
								error={!!errors.email}
								helperText={errors.email?.message}
							/>
						)}
					/>
					<Controller
						name="phone"
						control={control}
						rules={{
							required: "Phone no. is required",
							pattern: {
								value: /^[A-Z0-9._%+-]+@[A-Z0-9.-]+\.[A-Z]{2,}$/i,
								message: "Invalid Phone Number",
							},
							maxLength:{
								value:10,
								message:"Phone no must be 10 digits"
							}
							
						}}
						render={({ field }) => (
							<TextField
								{...field}
								margin="dense"
								label="Phone"
								type="tel"
								fullWidth
								variant="standard"
								error={!!errors.phone}
								helperText={errors.phone?.message}
							/>
						)}
					/>
					<Controller
						name="registeredAddress"
						control={control}
						rules={{
							required: "Address is required",
						}}
						render={({ field }) => (
							<TextField
								{...field}
								margin="dense"
								label="Address"
								type="text"
								fullWidth
								variant="standard"
								error={!!errors.registeredAddress}
								helperText={errors.registeredAddress?.message}
							/>
						)}
					/>
				</DialogContent>
				<DialogActions>
					<Button onClick={handleClose}>Cancel</Button>
					<Button type="submit">Save</Button>
				</DialogActions>
			</Dialog>
		</>
	);
};

export default AddEditCategoryModal;
